<?php

declare(strict_types=1);

namespace Drupal\hms_field\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Hooks class for hms field module.
 */
class HmsFieldHooks {

  /**
   * Implements hook_help().
   */
  #[Hook('help')]
  public function help($route_name, RouteMatchInterface $route_match): ?string {
    if ($route_name === 'help.page.hms_field') {
      // Main module help for the hms_field module.
      $output = '<h3>' . t('About') . '</h3>';
      $output .= '<p>' . t('Provides a field for Hours, Minutes and Seconds stored as seconds.') . '</p>';
      return $output;
    }
    return NULL;
  }

  /**
   * Implements hook_theme().
   */
  #[Hook('theme')]
  public function theme(): array {
    return [
      'hms' => [
        'variables' => [
          'value' => 0,
          'format' => 'h:mm',
          'leading_zero' => TRUE,
          'running_since' => 0,
          'offset' => 0,
          'default_value' => 0,
        ],
      ],
      'hms_natural_language' => [
        'variables' => [
          'value' => 0,
          'format' => 'w:d:h:m:s',
          'separator' => ', ',
          'last_separator' => ' and ',
        ],
      ],
    ];
  }

}
